@@ -2,9 +2,10 @@
 # -*- coding: utf-8 -*-
 
 
+import os
 import sys
-sys.path.append('..')
+sys.path.insert(0, os.path.abspath('../'))
 
-if sys.version_info[0] == 2:
+if sys.version_info < (3,):
     reload(sys)
     sys.setdefaultencoding('utf-8')
